@@ -57,7 +57,7 @@ class PackageBuild:
 
         a = run_shell("git remote -v", printf=False)
         git_url = a.split('\n')[0].split('\t')[1].split(' ')[0]
-        run_shell_list(['pip install -U -q git+{}'.format(git_url), ])
+        run_shell('pip install -U -q git+{}'.format(git_url))
         logger.info('pip install {} success'.format(self.name))
 
     def git_clear_build(self):
