@@ -5,7 +5,7 @@ class VersionManage:
     def __init__(self, version_path='./script/__version__.md', step=16):
         self.step = step
         self.version_path = version_path
-        self.version = self.read()
+        self.read()
 
     def add(self):
         step = self.step
